# import Saludos este es para importar todo el script
# from Saludos import saludar si tenemos más definiciones podemos agregarlas con comas
# from Saludos import saludar, Saludo
# from Saludos import * para importar todas las funciones o clases del módulo
from Mensajes.hola.Saludos import *
from Mensajes.adios.despedida import *

# Saludos.saludar()
saludar()
Saludo()

despedir()
Despedida()